// $Id: BasicSubjectVariablePatternVariable.java,v 1.7 2004/02/27 16:30:00 m31 Exp $
//
// This file is part of the program suite "Principia Mathematica II"
// which is a working prototype for the main project:
// "Hilbert II" - http://www.qedeq.org
//
// Copyright 2001-2004  Michael Meyling <mime@qedeq.org>.
//
// "Principia Mathematica II" is free software; you can redistribute
// it and/or modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.

package com.meyling.principia.logic.basic;


import com.meyling.principia.argument.Argument;
import com.meyling.principia.argument.ArgumentConstants;
import com.meyling.principia.argument.ArgumentException;
import com.meyling.principia.argument.Counter;
import com.meyling.principia.argument.PatternVariable;
import com.meyling.principia.argument.PatternVariables;


/**
 * Pattern variable, for matching purposes.
 *
 * @version $Revision: 1.7 $
 * @author  Michael Meyling
 */
public class BasicSubjectVariablePatternVariable extends PatternVariable
        implements SubjectVariableMarker {

    /** number of pattern variable */
    private final Counter number;

    /** assignment of pattern variable */
    private Argument argument = null;


    /**
     * Constructs a pattern variable.
     *
     * @param   arguments  first argument is number of this pattern
     *          variable
     * @throws  ArgumentException    if there is not exactly one
     *          argument that is an instance of {@link Counter}
     */
    public BasicSubjectVariablePatternVariable(final Argument[] arguments)
            throws ArgumentException {
        super(arguments);
        if (arguments.length != 1) {
            if (arguments.length == 0) {
                throw new ArgumentException(
                    ArgumentConstants.CODE_CONSTRUCTOR_WRONG_ARGUMENT_NUMBER,
                    ArgumentConstants.PATTERN_VARIABLE
                    + ArgumentConstants.OPERATOR_WITH_ONE_ARGUMENT);
            } else {
                throw new ArgumentException(
                    ArgumentConstants.CODE_CONSTRUCTOR_WRONG_ARGUMENT_NUMBER,
                    ArgumentConstants.PATTERN_VARIABLE
                    + ArgumentConstants.OPERATOR_WITH_ONE_ARGUMENT,
                    arguments[arguments.length - 1],
                    false);
            }
        }
        if (!(arguments[0] instanceof Counter)) {
            throw new ArgumentException(
                ArgumentConstants.CODE_CONSTRUCTOR_WRONG_ARGUMENT_TYPE,
                ArgumentConstants.PATTERN_VARIABLE
                + ArgumentConstants.FIRST_ARGUMENT_TYPE
                + ArgumentConstants.COUNTER,
                arguments[0]);
        }
        this.number = (Counter) arguments[0];
    }


    /**
     * Constructs a pattern variable.
     *
     * @param   number of this pattern variable
     * @throws  ArgumentException    if there couldn't be made a
     *          {@link Counter} out of <code>number</code>
     */
    public BasicSubjectVariablePatternVariable(final int number)
            throws ArgumentException {
        this(new Argument[] { new Counter(number) });
    }



    /** @inherited */
    public final PatternVariables getPatternVariables() {
        BasicPatternVariables variables = new BasicPatternVariables();
        variables.add(this);
        return variables;
    }


    /**
     * Is the argument matching the pattern variable?
     * Here true is returned if argument is an SubjectVariable.
     *
     * @param   argument    argument to match pattern variable
     * @return  <code>true</code>
     */
    public boolean isMatching(final Argument argument) {
        if (argument == null) {
            return false;
        }
        return argument instanceof SubjectVariable;
    }


    /** @inherited */
    public final Argument create(final Argument[] arguments)
            throws ArgumentException {
        return new BasicSubjectVariablePatternVariable(arguments);
    }


    /** @inherited */
    public final String toString() {
        return "@bx" + number.toString();
    }

}
