// $Id: Name.java,v 1.6 2004/02/27 16:30:00 m31 Exp $
//
// This file is part of the program suite "Principia Mathematica II"
// which is a working prototype for the main project:
// "Hilbert II" - http://www.qedeq.org
//
// Copyright 2001-2004  Michael Meyling <mime@qedeq.org>.
//
// "Principia Mathematica II" is free software; you can redistribute
// it and/or modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.

package com.meyling.principia.module;


import com.meyling.principia.argument.AbstractArgumentList;
import com.meyling.principia.argument.Argument;
import com.meyling.principia.argument.ArgumentException;
import com.meyling.principia.argument.Text;


/**
 * A reference label.
 *
 * @version $Revision: 1.6 $
 * @author  Michael Meyling
 */
public class Name extends AbstractArgumentList
        implements Argument, Textable {


    /**
     * Constructs a module name.
     *
     * @param   arguments    {@link Text} to be a name
     * @throws  ArgumentException    if there is not exactly one
     *          argument or the first argument is not an instance
     *          of {@link Text} or it isn't build of lowercase letters
     *          and digits.
     */
    public Name(final Argument[] arguments)
            throws ArgumentException {
        super(arguments);

        if (arguments.length != 1) {
            throw new ArgumentException(
                ModuleConstants.CODE_CONSTRUCTOR_WRONG_ARGUMENT_NUMBER,
                ModuleCreator.getName(this.getClass())
                + ModuleConstants.OPERATOR_WITH_ONE_ARGUMENT);
        }
        if (!(arguments[0] instanceof Text)) {
            throw new ArgumentException(
                ModuleConstants.CODE_CONSTRUCTOR_WRONG_ARGUMENT_TYPE,
                ModuleCreator.getName(this.getClass())
                + ModuleConstants.FIRST_ARGUMENT_TYPE
                + ModuleConstants.QUOTED_STRING,
            arguments[0]);
        }
        final String label = ((Text) arguments[0]).getText();
        if (label.length() == 0) {
            throw new ArgumentException(
                ModuleConstants.CODE_CONSTRUCTOR_WRONG_ARGUMENT_TYPE,
                ModuleCreator.getName(this.getClass())
                + ModuleConstants.NO_EMPTY_STRING,
                arguments[0]);
        }
        if (!label.toLowerCase().equals(label)) {
            throw new ArgumentException(
                ModuleConstants.CODE_CONSTRUCTOR_WRONG_ARGUMENT_TYPE,
                ModuleCreator.getName(this.getClass())
                + ModuleConstants.ONLY_LOWER_CASE_CHARS,
                arguments[0]);
        }
        if (!Character.isLetter(label.charAt(0))) {
            throw new ArgumentException(
                ModuleConstants.CODE_CONSTRUCTOR_WRONG_ARGUMENT_TYPE,
                ModuleCreator.getName(this.getClass())
                + ModuleConstants.MUST_START_WITH_LETTER,
                arguments[0]);
        }
        for (int i = 1; i < label.length(); i++) {
            if (!Character.isLetterOrDigit(label.charAt(i))) {
                throw new ArgumentException(
                    ModuleConstants.CODE_CONSTRUCTOR_WRONG_ARGUMENT_TYPE,
                    ModuleCreator.getName(this.getClass())
                    + ModuleConstants.MUST_BE_LETTER_DIGIT_STRING,
                    arguments[0]);
            }
        }
    }


    /**
     * Constructs a module name.
     *
     * @param   name     name of module
     * @throws  ArgumentException   if name isn't build of lowercase letters
     *          and digits
     */
    public Name(final String name)
            throws ArgumentException {
        this(new Argument[] { new Text(name) });
    }


    /** @inherited */
    public final String getText() {
        return ((Text) getArgument(0)).getText();
    }


    /** @inherited */
    public final Argument create(final Argument[] arguments)
            throws ArgumentException {
        return new Name(arguments);
    }


    /** @inherited */
    public final String toString() {
        return "Name " + getArgument(0).toString();
    }

}
